@@ -228,7 +228,7 @@ aliphatic <- function(seq, normalize=TRUE) {
 #' \enumerate{
 #'   \item  Moore DS. Amino acid and peptide net charges: A simple calculational procedure. 
 #'            Biochem Educ. 13, 10-11 (1985).
-#'   \item  \url{http://emboss.sourceforge.net/apps/cvs/emboss/apps/iep.html}
+#'   \item  \url{https://emboss.sourceforge.net/apps/cvs/emboss/apps/iep.html}
 #'   }
 #'   
 #' @seealso 
@@ -354,7 +354,7 @@ countOccurrences <- function(x, pattern) {
 #'          "TGTCAAAAGTATAACAGTGCCCCCTGGACGTTC")
 #' patterns <- c("A", "V", "[LI]")
 #' names(patterns) <- c("arg", "val", "iso_leu")
-#' countPatterns(seq, patterns, trim=TRUE, label="cdr3")
+#' countPatterns(seq, patterns, nt=TRUE, trim=TRUE, label="cdr3")
 #'             
 #' @export
 countPatterns <- function(seq, patterns, nt=TRUE, trim=FALSE, label="region") {
@@ -462,11 +462,11 @@ countPatterns <- function(seq, patterns, nt=TRUE, trim=FALSE, label="region") {
 #'   \item  Wu YC, et al. The relationship between CD27 negative and positive B cell 
 #'            populations in human peripheral blood. 
 #'            Front Immunol 2, 1-12 (2011).
-#'   \item  \url{http://emboss.sourceforge.net/apps/cvs/emboss/apps/iep.html}
+#'   \item  \url{https://emboss.sourceforge.net/apps/cvs/emboss/apps/iep.html}
 #' }
 #' 
 #' @seealso 
-#' See \link{countPatterns} for counting the occurance of specific amino acid subsequences.
+#' See \link{countPatterns} for counting the occurrence of specific amino acid subsequences.
 #' See \link{gravy}, \link{bulk}, \link{aliphatic}, \link{polar} and \link{charge} for functions 
 #' that calculate the included properties individually.
 #' 
@@ -543,7 +543,14 @@ aminoAcidProperties <- function(data, property=c("length", "gravy", "bulk",
     
     # Get sequence vector and translate if required
     region <- as.character(data[[seq]])
-    region_aa <- if (nt) { translateDNA(region, trim=trim) } else { region }
+    region_aa <- if (nt) { 
+        translateDNA(region, trim=trim) 
+    } else {
+        if (trim) {
+            region <- substr(region, 2, stri_length(region) - 1)
+        }
+        region
+    }
     
     ## Will retrieve properties for valid sequences only
     ## keep index to fill results data.frame
@@ -611,3 +618,4 @@ aminoAcidProperties <- function(data, property=c("length", "gravy", "bulk",
     data_cols <- colnames(data) %in% colnames(out_df) == FALSE
     return(cbind(data[, data_cols], out_df))
 }
+
