@@ -86,7 +86,7 @@ readChangeoDb <- function(file, select=NULL, drop=NULL, seq_upper=TRUE) {
     select_columns <- colnames(db)
     if(!is.null(select)) { select_columns <- intersect(select_columns, select) }
     if(!is.null(drop)) { select_columns <- setdiff(select_columns, drop) }
-    db <- dplyr::select(db, all_of(select_columns))
+    db <- select(db, dplyr::all_of(select_columns))
     
     # Convert sequence fields to upper case
     upper_cols <- intersect(seq_columns, names(db))
@@ -340,7 +340,7 @@ baseTheme <- function(sizing=c("figure", "window")) {
 #' @param   ncol   number of columns in the plot.
 #' @return  NULL
 #' 
-#' @seealso \link{ggplot}.
+#' @seealso \link[ggplot2]{ggplot}.
 #' 
 #' @references
 #' Modified from:
